@@ -1,6 +1,5 @@
 from enum import Enum
 from enum import EnumMeta
-from enum import auto
 from json import dump
 from operator import itemgetter
 from shutil import get_terminal_size
@@ -44,9 +43,9 @@ T = TypeVar("T")
 P = TypeVar("P")
 
 
-class OutputType(str, Enum):
-    rich = auto()
-    simple = auto()
+class OutputType(int, Enum):
+    rich = 1
+    simple = 2
 
 
 class Folder(str, Enum):
@@ -373,10 +372,11 @@ class Downloader:
             self.api.handle_delay()
             thumb = self.download_bytes(submission.thumbnail_url or thumbnail)
         self.db.submissions.save_submission({**format_entry(dict(submission), self.db.submissions.columns),
+                                             SubmissionsColumns.FILEURL.name: [submission.file_url],
                                              SubmissionsColumns.AUTHOR.name: submission.author.name,
                                              SubmissionsColumns.FAVORITE.name: {*favorites} if favorites else {},
                                              SubmissionsColumns.USERUPDATE.name: user_update},
-                                            file, thumb, replace=replace)
+                                            [file], thumb, replace=replace)
         if self.save_comments:
             save_comments(self.db, submissions_table, submission.id, submission.comments, replace=replace)
         self.db.commit()
@@ -392,7 +392,7 @@ class Downloader:
                              contains: Callable[[T], dict | None],
                              modify_checks: list[tuple[Callable[[T, dict], bool], str]],
                              save: tuple[Callable[[T, dict | None], int | None], str], stop: int = -1,
-                             clear_last_found: bool = False, clear_found: bool = False,
+                             clear_last_found: bool = False, clear_found: bool = False, replace_overwrite: bool = None
                              ) -> tuple[int, tuple[list[int | str], list[int | str], list[int | str]]]:
         entries_added: list[int | str] = []
         entries_modified: list[int | str] = []
@@ -442,7 +442,7 @@ class Downloader:
                 self.bar()
                 self.bar_message("SEARCHING")
                 db_entry: dict | None = contains(entry)
-                if db_entry and not self.replace:
+                if db_entry and not (replace_overwrite if replace_overwrite is not None else self.replace):
                     self.bar_message("IN DB", green, always=True)
                     if self.dry_run:
                         stop -= 1
@@ -516,7 +516,7 @@ class Downloader:
                                                      self.db.submissions.set_folder(submission.id, folder.value)),
                               "UPDATED")]
 
-        def save(sub_partial: SubmissionPartial, db_entry: dict | None,) -> int:
+        def save(sub_partial: SubmissionPartial, db_entry: dict | None, ) -> int:
             return self.download_submission(
                 sub_partial.id,
                 (db_entry or {}).get(SubmissionsColumns.USERUPDATE.name, False) or folder != Folder.favorites,
@@ -553,19 +553,18 @@ class Downloader:
                 return True
             return False
 
-        self.replace = False
         err, [entries_added, entries_modified, _entries_errors] = self.download_user_folder(
             user=user, folder=watchlist, downloader_entries=downloader, page_start=1,
             entry_id_getter=lambda u: u.name_url,
             entry_formats=("{0.status}{0.name}", ""),
             contains=lambda u: self.db.users[u.name_url],
             modify_checks=[(lambda w, e: check_folders(self.db, w, e), "UPDATED")],
-            save=(lambda watch: self.db.users.save_user(
+            save=(lambda watch, _db_entry: self.db.users.save_user(
                 {UsersColumns.USERNAME.value.name: watch.name_url,
                  UsersColumns.FOLDERS.value.name: set(folders),
                  UsersColumns.ACTIVE.value.name: True,
                  UsersColumns.USERPAGE.value.name: ""}), "ADDED"),
-            stop=-1, clear_found=clear_found
+            stop=-1, clear_found=clear_found, replace_overwrite=False
         )
         self.added_users.extend(entries_added)
         self.modified_users.extend(entries_modified)
